==> pandoc-2.9.2.1-11-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc
version:              2.9.2.1
visibility:           public
id:                   pandoc-2.9.2.1-FlWCin2PfE86GX9vmYXCLf
key:                  pandoc-2.9.2.1-FlWCin2PfE86GX9vmYXCLf
license:              GPL-2.0-only
copyright:            (c) 2006-2020 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. It can read several dialects of Markdown and
    (subsets of) HTML, reStructuredText, LaTeX, DocBook, JATS,
    MediaWiki markup, DokuWiki markup, TWiki markup,
    TikiWiki markup, Jira markup, Creole 1.0, Haddock markup,
    OPML, Emacs Org-Mode, Emacs Muse, txt2tags, ipynb (Jupyter
    notebooks), Vimwiki, Word Docx, ODT, EPUB, FictionBook2,
    roff man, Textile, and CSV, and it can write Markdown,
    reStructuredText, XHTML, HTML 5, LaTeX, ConTeXt, DocBook,
    JATS, OPML, TEI, OpenDocument, ODT, Word docx,
    PowerPoint pptx, RTF, MediaWiki, DokuWiki, XWiki,
    ZimWiki, Textile, Jira, roff man, roff ms, plain text,
    Emacs Org-Mode, AsciiDoc, Haddock markup,
    EPUB (v2 and v3), ipynb, FictionBook2,
    InDesign ICML, Muse, LaTeX beamer slides,
    and several kinds of HTML/JavaScript slide shows
    (S5, Slidy, Slideous, DZSlides, reveal.js).

    In contrast to most existing tools for converting Markdown
    to HTML, pandoc has a modular design: it consists of a set of
    readers, which parse text in a given format and produce a
    native representation of the document, and a set of writers,
    which convert this native representation into a target
    format. Thus, adding an input or output format requires
    only adding a reader or writer.

category:             Text
abi:                  d2403031e48a0412f0181be213144b8b
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify Text.Pandoc.BCP47
    Text.Pandoc.Class Text.Pandoc.Emoji Text.Pandoc.Error
    Text.Pandoc.Extensions Text.Pandoc.Filter Text.Pandoc.Highlighting
    Text.Pandoc.ImageSize Text.Pandoc.Logging Text.Pandoc.Lua
    Text.Pandoc.MIME Text.Pandoc.MediaBag Text.Pandoc.Options
    Text.Pandoc.PDF Text.Pandoc.Parsing Text.Pandoc.Process
    Text.Pandoc.Readers Text.Pandoc.Readers.CSV
    Text.Pandoc.Readers.CommonMark Text.Pandoc.Readers.Creole
    Text.Pandoc.Readers.DocBook Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.DokuWiki Text.Pandoc.Readers.EPUB
    Text.Pandoc.Readers.FB2 Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.Ipynb
    Text.Pandoc.Readers.JATS Text.Pandoc.Readers.Jira
    Text.Pandoc.Readers.LaTeX Text.Pandoc.Readers.LaTeX.Types
    Text.Pandoc.Readers.Man Text.Pandoc.Readers.Markdown
    Text.Pandoc.Readers.MediaWiki Text.Pandoc.Readers.Muse
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.Textile Text.Pandoc.Readers.TikiWiki
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.Readers.Vimwiki
    Text.Pandoc.SelfContained Text.Pandoc.Shared Text.Pandoc.Templates
    Text.Pandoc.UTF8 Text.Pandoc.Writers Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.CommonMark Text.Pandoc.Writers.ConTeXt
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.XWiki Text.Pandoc.Writers.ZimWiki
    Text.Pandoc.XML

hidden-modules:
    Prelude Text.Pandoc.App.CommandLineOptions
    Text.Pandoc.App.FormatHeuristics Text.Pandoc.App.Opt
    Text.Pandoc.App.OutputSettings Text.Pandoc.Class.CommonState
    Text.Pandoc.Class.PandocMonad Text.Pandoc.Class.PandocIO
    Text.Pandoc.Class.PandocPure Text.Pandoc.Filter.JSON
    Text.Pandoc.Filter.Lua Text.Pandoc.Filter.Path
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Fields Text.Pandoc.Readers.LaTeX.Parsing
    Text.Pandoc.Readers.LaTeX.Lang Text.Pandoc.Readers.Odt.Base
    Text.Pandoc.Readers.Odt.Namespaces
    Text.Pandoc.Readers.Odt.StyleReader
    Text.Pandoc.Readers.Odt.ContentReader
    Text.Pandoc.Readers.Odt.Generic.Fallible
    Text.Pandoc.Readers.Odt.Generic.SetMap
    Text.Pandoc.Readers.Odt.Generic.Utils
    Text.Pandoc.Readers.Odt.Generic.Namespaces
    Text.Pandoc.Readers.Odt.Generic.XMLConverter
    Text.Pandoc.Readers.Odt.Arrows.State
    Text.Pandoc.Readers.Odt.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshaling Text.Pandoc.Lua.Marshaling.AST
    Text.Pandoc.Lua.Marshaling.AnyValue
    Text.Pandoc.Lua.Marshaling.CommonState
    Text.Pandoc.Lua.Marshaling.Context Text.Pandoc.Lua.Marshaling.List
    Text.Pandoc.Lua.Marshaling.MediaBag
    Text.Pandoc.Lua.Marshaling.ReaderOptions
    Text.Pandoc.Lua.Marshaling.Version Text.Pandoc.Lua.Module.MediaBag
    Text.Pandoc.Lua.Module.Pandoc Text.Pandoc.Lua.Module.System
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Packages Text.Pandoc.Lua.Util Text.Pandoc.Lua.Walk
    Text.Pandoc.CSS Text.Pandoc.CSV Text.Pandoc.RoffChar
    Text.Pandoc.UUID Text.Pandoc.Translations Text.Pandoc.Slides
    Text.Pandoc.Image Paths_pandoc

import-dirs:          /usr/lib/ghc-8.8.3/site-local/pandoc-2.9.2.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pandoc-2.9.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc
hs-libraries:         HSpandoc-2.9.2.1-FlWCin2PfE86GX9vmYXCLf
depends:
    Glob-0.10.0-63hwg0fQ3iz6ZzdnMP6GTK
    HTTP-4000.3.14-GBXtH6AIwlmCwA1pTgj3ER
    HsYAML-0.2.1.0-hXbXGBWBMQ9GFFdDgklOL
    JuicyPixels-3.3.5-H3jwZH8gDcNJVCkAjfPCdT
    SHA-1.6.4.4-CHsxGcusOx3C58H7oeK6ja
    aeson-1.4.7.1-D2ldL4AX1zOJH6OUZhNdCi
    aeson-pretty-0.8.8-Bhht8284pN8KBgNDmWtZyE
    attoparsec-0.13.2.4-E6tYZWwzvMCzu2pmoxmmw
    base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2
    base-noprelude-4.13.0.0-5e7lkjQlDgkKqNhcMNAdhu
    base64-bytestring-1.0.0.3-DTCbOaco5j9FDaHscqEylF binary-0.8.7.0
    blaze-html-0.9.1.2-5SOQeKwiKRaDWK8K92Y56k
    blaze-markup-0.8.2.4-JyeEz8woeul42iAs1i68u0 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-3LxascOG9NyOAHOHCLtzq
    cmark-gfm-0.2.1-XE8zH5SBK42O0IumnfbXR containers-0.6.2.1
    data-default-0.7.1.1-KwmPSgEEmCp4io60ICryCw deepseq-1.4.4.0
    directory-1.3.6.0 doclayout-0.3-1wCZdL1Z7b35MwTts89HXh
    doctemplates-0.8.1-1sqcpUaldIv1BplQH1KYjA
    emojis-0.1-EGeo19AQ8dwKQOXNS1BLTr
    exceptions-0.10.4-ElKsHaIv8kxGE3x6lSFI2 filepath-1.4.2.1
    haddock-library-1.8.0-CkcemwFyFHC9NIKBmJH0qe
    hslua-1.1.0-6HCbpSak3uT8srZLOZZJhR
    hslua-module-system-0.2.1-AyGC55bwLHR5EiO5nIg9JB
    hslua-module-text-0.2.1-8tG6sz0fHikAebpwhuyhb
    http-client-0.6.4.1-1kz7p9SOLSK6QX3EAAeLDN
    http-client-tls-0.3.5.3-KH0uYXSDphf9YjOHRygRK9
    http-types-0.12.3-GkYJLrkrgii59d3GHtR3Sa
    ipynb-0.1-HMz6vNRqtHy7PbWWEuGqtb
    jira-wiki-markup-1.1.4-5Ndxyo2jT1nJAoQxth850s mtl-2.2.2
    network-3.1.1.1-5FgtrTFHUQaFQhXHTS1i9u
    network-uri-2.6.3.0-23ecXQj6xJbD3Cu3aUxELQ
    pandoc-types-1.20-CeY4C0n5SsvLyLjI6d2tqP parsec-3.1.14.0
    process-1.6.8.0 random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    safe-0.3.18-77EtIZs3AFB4iOmOvdspYk
    scientific-0.3.6.2-L23NT81Suoi4KfELghMhed
    skylighting-0.8.3.4-GxhoeNMPfn5LydqGPvqDt4
    skylighting-core-0.8.3.4-4M4O5iJZpPGJZO8Bkg74tD
    split-0.2.3.4-2SLh24GWGfv9bpFm6zqb4X
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    tagsoup-0.14.8-7ifmw2h5LKqFE6tAnvByQ4
    temporary-1.3-BiFXPx2xjAKDOblp9pWkcg
    texmath-0.12.0.1-AVVvR4qjAeA2QV4gs33MQy text-1.2.4.0
    text-conversions-0.3.0-FJdp7DLexZwCxexndqJB1L time-1.9.3
    unicode-transforms-0.3.6-GUnRbIsZoIJ1qD9U75iqKf unix-2.7.2.2
    unordered-containers-0.2.10.0-A1cNogzO5wQ33Xk0bjeyDo
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
    zip-archive-0.4.1-6dxYk3kYGSJKBzqhOpExr
    zlib-0.6.2.1-CYgtdz0O92NHvS2vBB2HG4

haddock-interfaces:   /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> pandoc-2.9.2.1-22-x86_64.pkg.tar.zst: usr/share/haskell/register/pandoc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc
version:              2.9.2.1
visibility:           public
id:                   pandoc-2.9.2.1-3huwXWukYbv8AdgrRAnJDn
key:                  pandoc-2.9.2.1-3huwXWukYbv8AdgrRAnJDn
license:              GPL-2.0-only
copyright:            (c) 2006-2020 John MacFarlane
maintainer:           John MacFarlane <jgm@berkeley.edu>
author:               John MacFarlane <jgm@berkeley.edu>
stability:            alpha
homepage:             https://pandoc.org
synopsis:             Conversion between markup formats
description:
    Pandoc is a Haskell library for converting from one markup
    format to another, and a command-line tool that uses
    this library. It can read several dialects of Markdown and
    (subsets of) HTML, reStructuredText, LaTeX, DocBook, JATS,
    MediaWiki markup, DokuWiki markup, TWiki markup,
    TikiWiki markup, Jira markup, Creole 1.0, Haddock markup,
    OPML, Emacs Org-Mode, Emacs Muse, txt2tags, ipynb (Jupyter
    notebooks), Vimwiki, Word Docx, ODT, EPUB, FictionBook2,
    roff man, Textile, and CSV, and it can write Markdown,
    reStructuredText, XHTML, HTML 5, LaTeX, ConTeXt, DocBook,
    JATS, OPML, TEI, OpenDocument, ODT, Word docx,
    PowerPoint pptx, RTF, MediaWiki, DokuWiki, XWiki,
    ZimWiki, Textile, Jira, roff man, roff ms, plain text,
    Emacs Org-Mode, AsciiDoc, Haddock markup,
    EPUB (v2 and v3), ipynb, FictionBook2,
    InDesign ICML, Muse, LaTeX beamer slides,
    and several kinds of HTML/JavaScript slide shows
    (S5, Slidy, Slideous, DZSlides, reveal.js).

    In contrast to most existing tools for converting Markdown
    to HTML, pandoc has a modular design: it consists of a set of
    readers, which parse text in a given format and produce a
    native representation of the document, and a set of writers,
    which convert this native representation into a target
    format. Thus, adding an input or output format requires
    only adding a reader or writer.

category:             Text
abi:                  b43785f78cfb66c2e5cd604c26e50e0b
exposed:              True
exposed-modules:
    Text.Pandoc Text.Pandoc.App Text.Pandoc.Asciify Text.Pandoc.BCP47
    Text.Pandoc.Class Text.Pandoc.Emoji Text.Pandoc.Error
    Text.Pandoc.Extensions Text.Pandoc.Filter Text.Pandoc.Highlighting
    Text.Pandoc.ImageSize Text.Pandoc.Logging Text.Pandoc.Lua
    Text.Pandoc.MIME Text.Pandoc.MediaBag Text.Pandoc.Options
    Text.Pandoc.PDF Text.Pandoc.Parsing Text.Pandoc.Process
    Text.Pandoc.Readers Text.Pandoc.Readers.CSV
    Text.Pandoc.Readers.CommonMark Text.Pandoc.Readers.Creole
    Text.Pandoc.Readers.DocBook Text.Pandoc.Readers.Docx
    Text.Pandoc.Readers.DokuWiki Text.Pandoc.Readers.EPUB
    Text.Pandoc.Readers.FB2 Text.Pandoc.Readers.HTML
    Text.Pandoc.Readers.Haddock Text.Pandoc.Readers.Ipynb
    Text.Pandoc.Readers.JATS Text.Pandoc.Readers.Jira
    Text.Pandoc.Readers.LaTeX Text.Pandoc.Readers.LaTeX.Types
    Text.Pandoc.Readers.Man Text.Pandoc.Readers.Markdown
    Text.Pandoc.Readers.MediaWiki Text.Pandoc.Readers.Muse
    Text.Pandoc.Readers.Native Text.Pandoc.Readers.OPML
    Text.Pandoc.Readers.Odt Text.Pandoc.Readers.Org
    Text.Pandoc.Readers.RST Text.Pandoc.Readers.TWiki
    Text.Pandoc.Readers.Textile Text.Pandoc.Readers.TikiWiki
    Text.Pandoc.Readers.Txt2Tags Text.Pandoc.Readers.Vimwiki
    Text.Pandoc.SelfContained Text.Pandoc.Shared Text.Pandoc.Templates
    Text.Pandoc.UTF8 Text.Pandoc.Writers Text.Pandoc.Writers.AsciiDoc
    Text.Pandoc.Writers.CommonMark Text.Pandoc.Writers.ConTeXt
    Text.Pandoc.Writers.Custom Text.Pandoc.Writers.Docbook
    Text.Pandoc.Writers.Docx Text.Pandoc.Writers.DokuWiki
    Text.Pandoc.Writers.EPUB Text.Pandoc.Writers.FB2
    Text.Pandoc.Writers.HTML Text.Pandoc.Writers.Haddock
    Text.Pandoc.Writers.ICML Text.Pandoc.Writers.Ipynb
    Text.Pandoc.Writers.JATS Text.Pandoc.Writers.Jira
    Text.Pandoc.Writers.LaTeX Text.Pandoc.Writers.Man
    Text.Pandoc.Writers.Markdown Text.Pandoc.Writers.Math
    Text.Pandoc.Writers.MediaWiki Text.Pandoc.Writers.Ms
    Text.Pandoc.Writers.Muse Text.Pandoc.Writers.Native
    Text.Pandoc.Writers.ODT Text.Pandoc.Writers.OOXML
    Text.Pandoc.Writers.OPML Text.Pandoc.Writers.OpenDocument
    Text.Pandoc.Writers.Org Text.Pandoc.Writers.Powerpoint
    Text.Pandoc.Writers.RST Text.Pandoc.Writers.RTF
    Text.Pandoc.Writers.Shared Text.Pandoc.Writers.TEI
    Text.Pandoc.Writers.Texinfo Text.Pandoc.Writers.Textile
    Text.Pandoc.Writers.XWiki Text.Pandoc.Writers.ZimWiki
    Text.Pandoc.XML

hidden-modules:
    Prelude Text.Pandoc.App.CommandLineOptions
    Text.Pandoc.App.FormatHeuristics Text.Pandoc.App.Opt
    Text.Pandoc.App.OutputSettings Text.Pandoc.Class.CommonState
    Text.Pandoc.Class.PandocMonad Text.Pandoc.Class.PandocIO
    Text.Pandoc.Class.PandocPure Text.Pandoc.Filter.JSON
    Text.Pandoc.Filter.Lua Text.Pandoc.Filter.Path
    Text.Pandoc.Readers.Docx.Lists Text.Pandoc.Readers.Docx.Combine
    Text.Pandoc.Readers.Docx.Parse
    Text.Pandoc.Readers.Docx.Parse.Styles Text.Pandoc.Readers.Docx.Util
    Text.Pandoc.Readers.Docx.Fields Text.Pandoc.Readers.LaTeX.Parsing
    Text.Pandoc.Readers.LaTeX.Lang Text.Pandoc.Readers.Odt.Base
    Text.Pandoc.Readers.Odt.Namespaces
    Text.Pandoc.Readers.Odt.StyleReader
    Text.Pandoc.Readers.Odt.ContentReader
    Text.Pandoc.Readers.Odt.Generic.Fallible
    Text.Pandoc.Readers.Odt.Generic.SetMap
    Text.Pandoc.Readers.Odt.Generic.Utils
    Text.Pandoc.Readers.Odt.Generic.Namespaces
    Text.Pandoc.Readers.Odt.Generic.XMLConverter
    Text.Pandoc.Readers.Odt.Arrows.State
    Text.Pandoc.Readers.Odt.Arrows.Utils
    Text.Pandoc.Readers.Org.BlockStarts Text.Pandoc.Readers.Org.Blocks
    Text.Pandoc.Readers.Org.DocumentTree
    Text.Pandoc.Readers.Org.ExportSettings
    Text.Pandoc.Readers.Org.Inlines Text.Pandoc.Readers.Org.Meta
    Text.Pandoc.Readers.Org.ParserState Text.Pandoc.Readers.Org.Parsing
    Text.Pandoc.Readers.Org.Shared Text.Pandoc.Readers.Metadata
    Text.Pandoc.Readers.Roff Text.Pandoc.Writers.Docx.StyleMap
    Text.Pandoc.Writers.Roff
    Text.Pandoc.Writers.Powerpoint.Presentation
    Text.Pandoc.Writers.Powerpoint.Output Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshaling Text.Pandoc.Lua.Marshaling.AST
    Text.Pandoc.Lua.Marshaling.AnyValue
    Text.Pandoc.Lua.Marshaling.CommonState
    Text.Pandoc.Lua.Marshaling.Context Text.Pandoc.Lua.Marshaling.List
    Text.Pandoc.Lua.Marshaling.MediaBag
    Text.Pandoc.Lua.Marshaling.ReaderOptions
    Text.Pandoc.Lua.Marshaling.Version Text.Pandoc.Lua.Module.MediaBag
    Text.Pandoc.Lua.Module.Pandoc Text.Pandoc.Lua.Module.System
    Text.Pandoc.Lua.Module.Types Text.Pandoc.Lua.Module.Utils
    Text.Pandoc.Lua.Packages Text.Pandoc.Lua.Util Text.Pandoc.Lua.Walk
    Text.Pandoc.CSS Text.Pandoc.CSV Text.Pandoc.RoffChar
    Text.Pandoc.UUID Text.Pandoc.Translations Text.Pandoc.Slides
    Text.Pandoc.Image Paths_pandoc

import-dirs:          /usr/lib/ghc-8.8.3/site-local/pandoc-2.9.2.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pandoc-2.9.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/pandoc
hs-libraries:         HSpandoc-2.9.2.1-3huwXWukYbv8AdgrRAnJDn
depends:
    Glob-0.10.0-63hwg0fQ3iz6ZzdnMP6GTK
    HTTP-4000.3.14-DuDQWbQTaJcD3ZGRhnTFuz
    HsYAML-0.2.1.0-hXbXGBWBMQ9GFFdDgklOL
    JuicyPixels-3.3.5-H3jwZH8gDcNJVCkAjfPCdT
    SHA-1.6.4.4-CHsxGcusOx3C58H7oeK6ja
    aeson-1.4.7.1-2vh3WJvM2HmJTL8YxIIpzz
    aeson-pretty-0.8.8-2KjwTwJSw0cEqwM2dNRb96
    attoparsec-0.13.2.4-E6tYZWwzvMCzu2pmoxmmw
    base-compat-0.11.1-4oueEGUxmwHC6tuHqQ6hE2
    base-noprelude-4.13.0.0-5e7lkjQlDgkKqNhcMNAdhu
    base64-bytestring-1.0.0.3-DTCbOaco5j9FDaHscqEylF binary-0.8.7.0
    blaze-html-0.9.1.2-HWPU069zWYoGOHIEzIp7fI
    blaze-markup-0.8.2.5-HYuwOkDPD9NKwukg1t3P bytestring-0.10.10.0
    case-insensitive-1.2.1.0-3LxascOG9NyOAHOHCLtzq
    cmark-gfm-0.2.1-XE8zH5SBK42O0IumnfbXR containers-0.6.2.1
    data-default-0.7.1.1-KwmPSgEEmCp4io60ICryCw deepseq-1.4.4.0
    directory-1.3.6.0 doclayout-0.3-FFmnYXHb0avGq8sclUxTHT
    doctemplates-0.8.2-8ueU5aWL3VR1nKK980lqpR
    emojis-0.1-EGeo19AQ8dwKQOXNS1BLTr
    exceptions-0.10.4-ElKsHaIv8kxGE3x6lSFI2 filepath-1.4.2.1
    haddock-library-1.8.0-LaszPQ6CS5lBQIci97bQ4D
    hslua-1.1.0-6HCbpSak3uT8srZLOZZJhR
    hslua-module-system-0.2.1-AyGC55bwLHR5EiO5nIg9JB
    hslua-module-text-0.2.1-8tG6sz0fHikAebpwhuyhb
    http-client-0.6.4.1-10PbGoSzPL3LsOfCQJvSRo
    http-client-tls-0.3.5.3-LRubWbtJpAyJAQlnyKN2ag
    http-types-0.12.3-GkYJLrkrgii59d3GHtR3Sa
    ipynb-0.1-FzMEY1vG85Z3IXyiOkWXpA
    jira-wiki-markup-1.1.4-5Ndxyo2jT1nJAoQxth850s mtl-2.2.2
    network-3.1.1.1-5FgtrTFHUQaFQhXHTS1i9u
    network-uri-2.6.3.0-8RUTSqJaAoUBpXV3zWRZ86
    pandoc-types-1.20-3CnMlP0pm198aFWGunQUW9 parsec-3.1.14.0
    process-1.6.8.0 random-1.1-CUqV1zxrwrE4K5XCdTZSYy
    safe-0.3.18-77EtIZs3AFB4iOmOvdspYk
    scientific-0.3.6.2-L23NT81Suoi4KfELghMhed
    skylighting-0.8.3.4-Gj7aZV42ydqZjVUHmTBEQ
    skylighting-core-0.8.3.4-2SxyLH9luBgLcAwkw3lmLr
    split-0.2.3.4-2SLh24GWGfv9bpFm6zqb4X
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM
    tagsoup-0.14.8-7ifmw2h5LKqFE6tAnvByQ4
    temporary-1.3-BiFXPx2xjAKDOblp9pWkcg
    texmath-0.12.0.2-KuxcqoZK3CRCZmwfrv5B1L text-1.2.4.0
    text-conversions-0.3.0-FJdp7DLexZwCxexndqJB1L time-1.9.3
    unicode-transforms-0.3.6-GUnRbIsZoIJ1qD9U75iqKf unix-2.7.2.2
    unordered-containers-0.2.10.0-A1cNogzO5wQ33Xk0bjeyDo
    vector-0.12.1.2-C2W44iPdAFeHo4yLU081Gd
    xml-1.3.14-IT4S7IkihY28IGBFVjHe4u
    zip-archive-0.4.1-6dxYk3kYGSJKBzqhOpExr
    zlib-0.6.2.1-CYgtdz0O92NHvS2vBB2HG4

haddock-interfaces:   /usr/share/doc/pandoc/html/pandoc.haddock
haddock-html:         /usr/share/doc/pandoc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
